@@ -3,10 +3,9 @@ use lightspeed_core::service::auth::Owned;
 use lightspeed_core::service::validator::must_match::validate_must_be_equals;
 use lightspeed_core::service::validator::Validable;
 use serde::{Deserialize, Serialize};
-use typescript_definitions::TypeScriptify;
 
-#[derive(Serialize, Deserialize, TypeScriptify)]
-#[serde(rename_all = "camelCase")]
+#[derive(Serialize, Deserialize)]
+#[cfg_attr(feature = "poem_openapi", derive(poem_openapi::Object))]
 pub struct ChangePasswordDto {
     pub user_id: i64,
     pub old_password: String,
