@@ -1,9 +1,8 @@
 use lightspeed_core::model::language::Language;
 use serde::{Deserialize, Serialize};
-use typescript_definitions::TypeScriptify;
 
-#[derive(Serialize, Deserialize, TypeScriptify)]
-#[serde(rename_all = "camelCase")]
+#[derive(Serialize, Deserialize)]
+#[cfg_attr(feature = "poem_openapi", derive(poem_openapi::Object))]
 pub struct SendResetPasswordDto {
     pub email: String,
     pub language: Language,
